Changelog
=========

## Next Release
* Moved repository:  
  from https://github.com/neo4j-drivers/neo4j-python-driver-rust-ext  
  to https://github.com/neo4j/neo4j-python-driver-rust-ext
* Metadata: removed `Beta` tag, added `Production/Stable`.
* Bump MSRV (minimum supported Rust version) to 1.67.0.
* Clarify installation documentation: `neo4j` and `neo4j-rust-ext` can both be installed at the same time.
  ℹ️ Make sure to specify matching versions if you do so.


## 5.23.0.0 (2024-07-29)
* Target driver version 5.23.0


## 5.22.0.0 (2024-06-27)
* Target driver version 5.22.0


## 5.21.0.0 (2024-06-11)
* Target driver version 5.21.0


## 5.20.0.0 (2024-04-26)
* Target driver version 5.20.0


## 5.19.0.0 (2024-05-02)
* Target driver version 5.19.0


## 5.18.0.0 (2024-02-29)
* Target driver version 5.18.0


## 5.17.0.0b1 (2024-01-29)
* Target driver version 5.17.0


## 5.16.0.0b1 (2023-12-28)
* Target driver version 5.16.0


## 5.15.0.0b1 (2023-11-28)
* Target driver version 5.15.0


## 5.14.1.0a1 (2023-11-03)
* Target driver version 5.14.1
* Initial release.
